@@ -8,7 +8,7 @@ from neo.Core.TX.MinerTransaction import MinerTransaction
 from neo.Network.NeoNode import NeoNode
 from neo.Settings import settings
 from twisted.internet.protocol import ReconnectingClientFactory
-from twisted.internet import reactor
+from twisted.internet import reactor, task
 
 
 class NeoClientFactory(ReconnectingClientFactory):
@@ -16,6 +16,15 @@ class NeoClientFactory(ReconnectingClientFactory):
     maxRetries = 1
 
     def clientConnectionFailed(self, connector, reason):
+        address = "%s:%s" % (connector.host, connector.port)
+        logger.debug("Failed connecting to %s " % address)
+        if "Connection refused" in str(reason) or "Operation timed out" in str(reason):
+            if address in NodeLeader.Instance().ADDRS:
+                NodeLeader.Instance().ADDRS.remove(address)
+                if address not in NodeLeader.Instance().DEAD_ADDRS:
+                    NodeLeader.Instance().DEAD_ADDRS.append(address)
+
+    def clientConnectionLost(self, connector, reason):
         address = "%s:%s" % (connector.host, connector.port)
         logger.debug("Dropped connection from %s " % address)
         for peer in NodeLeader.Instance().Peers:
@@ -31,13 +40,13 @@ class NodeLeader:
     UnconnectedPeers = []
 
     ADDRS = []
+    DEAD_ADDRS = []
 
     NodeId = None
 
     _MissedBlocks = []
 
     BREQPART = 100
-    NREQMAX = 500
     BREQMAX = 10000
 
     KnownHashes = []
@@ -49,6 +58,8 @@ class NodeLeader:
 
     ServiceEnabled = False
 
+    peer_check_loop = None
+
     @staticmethod
     def Instance():
         """
@@ -79,12 +90,18 @@ class NodeLeader:
         self.Peers = []
         self.UnconnectedPeers = []
         self.ADDRS = []
+        self.DEAD_ADDRS = []
         self.MissionsGlobal = []
         self.NodeId = random.randint(1294967200, 4294967200)
 
     def Restart(self):
+        if self.peer_check_loop:
+            self.peer_check_loop.stop()
+            self.peer_check_loop = None
+
         if len(self.Peers) == 0:
             self.ADDRS = []
+            self.DEAD_ADDRS = []
             self.Start()
 
     def Start(self):
@@ -93,22 +110,52 @@ class NodeLeader:
         start_delay = 0
         for bootstrap in settings.SEED_LIST:
             host, port = bootstrap.split(":")
-            self.ADDRS.append('%s:%s' % (host, port))
             reactor.callLater(start_delay, self.SetupConnection, host, port)
             start_delay += 1
 
+        # check in on peers every 4 mins
+        self.peer_check_loop = task.LoopingCall(self.PeerCheckLoop)
+        self.peer_check_loop.start(240, now=False)
+
+    def setBlockReqSizeAndMax(self, breqpart=0, breqmax=0):
+        if breqpart > 0 and breqmax > 0 and breqmax > breqpart:
+            self.BREQPART = breqpart
+            self.BREQMAX = breqmax
+            logger.info("Set each node to request %s blocks per request with a total of %s in queue" % (self.BREQPART, self.BREQMAX))
+        else:
+            logger.info("invalid values. Please specify a block request part and max size for each node, like 30 and 1000")
+
+    def setBlockReqSizeByName(self, name):
+        if name.lower() == 'slow':
+            self.BREQPART = 15
+            self.BREQMAX = 5000
+        elif name.lower() == 'normal':
+            self.BREQPART = 100
+            self.BREQMAX = 10000
+        elif name.lower() == 'fast':
+            self.BREQPART = 250
+            self.BREQMAX = 15000
+        else:
+            logger.info("configuration name %s not found. use 'slow', 'normal', or 'fast'" % name)
+
+        logger.info("Set each node to request %s blocks per request with a total of %s in queue" % (self.BREQPART, self.BREQMAX))
+
     def RemoteNodePeerReceived(self, host, port, index):
         addr = '%s:%s' % (host, port)
-        if addr not in self.ADDRS and len(self.Peers) < settings.CONNECTED_PEER_MAX:
+        if addr not in self.ADDRS and len(self.Peers) < settings.CONNECTED_PEER_MAX and addr not in self.DEAD_ADDRS:
             self.ADDRS.append(addr)
             reactor.callLater(index * 10, self.SetupConnection, host, port)
 
     def SetupConnection(self, host, port):
         if len(self.Peers) < settings.CONNECTED_PEER_MAX:
-            reactor.connectTCP(host, int(port), NeoClientFactory())
+            reactor.connectTCP(host, int(port), NeoClientFactory(), timeout=120)
 
     def Shutdown(self):
         """Disconnect all connected peers."""
+        if self.peer_check_loop:
+            self.peer_check_loop.stop()
+            self.peer_check_loop = None
+
         for p in self.Peers:
             p.Disconnect()
 
@@ -124,6 +171,8 @@ class NodeLeader:
 
             if len(self.Peers) < settings.CONNECTED_PEER_MAX:
                 self.Peers.append(peer)
+                if peer.Address not in self.ADDRS:
+                    self.ADDRS.append(peer.Address)
             else:
                 if peer.Address in self.ADDRS:
                     self.ADDRS.remove(peer.Address)
@@ -138,12 +187,21 @@ class NodeLeader:
         """
         if peer in self.Peers:
             self.Peers.remove(peer)
-        if peer.Address in self.ADDRS:
-            self.ADDRS.remove(peer.Address)
-        if len(self.Peers) == 1:
-            self.Peers[0].Disconnect()
-        elif len(self.Peers) == 0:
-            reactor.callLater(10, self.Restart)
+
+    def PeerCheckLoop(self):
+        # often times things will get stuck on 1 peer so
+        # every so often we will try to reconnect to peers
+        # that were previously active but lost their connection
+
+        start_delay = 0
+        connected = []
+        for peer in self.Peers:
+            connected.append(peer.Address)
+        for addr in self.ADDRS:
+            if addr not in connected and len(self.Peers) < settings.CONNECTED_PEER_MAX and addr not in self.DEAD_ADDRS:
+                host, port = addr.split(":")
+                reactor.callLater(start_delay, self.SetupConnection, host, port)
+                start_delay += 1
 
     def ResetBlockRequestsAndCache(self):
         """Reset the block request counter and its cache."""
